@@ -1,7 +1,6 @@
-package Pcore::API::Majestic v0.5.3;
+package Pcore::API::Majestic v0.6.0;
 
-use Pcore -dist, -class, -const, -export => { CONST => [qw[$MAJESTIC_INDEX_FRESH $MAJESTIC_INDEX_HISTORIC]] };
-use Pcore::API::Response;
+use Pcore -dist, -class, -const, -status, -export => { CONST => [qw[$MAJESTIC_INDEX_FRESH $MAJESTIC_INDEX_HISTORIC]] };
 
 const our $MAJESTIC_INDEX_FRESH    => 1;
 const our $MAJESTIC_INDEX_HISTORIC => 2;
@@ -79,21 +78,19 @@ sub _request ( $self, $url_params, $cb ) {
             my $api_res;
 
             if ( $res->status != 200 ) {
-                $api_res = Pcore::API::Response->new( { status => $res->status, reason => $res->reason } );
+                $api_res = status [ $res->status, $res->reason ];
             }
             else {
                 my $json = eval { P->data->from_json( $res->body->$* ); };
 
                 if ($@) {
-                    $api_res = Pcore::API::Response->new( { status => 999, reason => 'Invalid JSON body' } );
+                    $api_res = status [ 999, 'Invalid JSON body' ];
                 }
                 elsif ( $json->{Code} ne 'OK' ) {
-                    $api_res = Pcore::API::Response->new( { status => 999, reason => $json->{ErrorMessage} } );
+                    $api_res = status [ 999, $json->{ErrorMessage} ];
                 }
                 else {
-                    $api_res = Pcore::API::Response->new( { status => 200 } );
-
-                    $api_res->{result} = $json;
+                    $api_res = status 200, $json;
                 }
             }
 
